==> alpha-proc-1.8.2-sources.jar: org/neo4j/gds/scaling/ScalePropertiesProc.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.gds.scaling;

import org.neo4j.gds.AlgoBaseProc;
import org.neo4j.gds.api.NodeProperties;
import org.neo4j.gds.api.nodeproperties.DoubleArrayNodeProperties;

public class ScalePropertiesProc {

    static NodeProperties nodeProperties(AlgoBaseProc.ComputationResult<ScaleProperties, ScaleProperties.Result, ? extends ScalePropertiesBaseConfig> computationResult) {
        var size = computationResult.graph().nodeCount();
        var scaledProperties = computationResult.result().scaledProperties();

        return new DoubleArrayNodeProperties() {
            @Override
            public long size() {
                return size;
            }

            @Override
            public double[] doubleArrayValue(long nodeId) {
                return scaledProperties.get(nodeId);
            }
        };
    }
}

==> alpha-proc-2.1.9-sources.jar: org/neo4j/gds/scaling/ScalePropertiesProc.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.gds.scaling;

import org.neo4j.gds.api.properties.nodes.DoubleArrayNodePropertyValues;
import org.neo4j.gds.api.properties.nodes.NodePropertyValues;
import org.neo4j.gds.executor.ComputationResult;

public class ScalePropertiesProc {

    static NodePropertyValues nodeProperties(ComputationResult<ScaleProperties, ScaleProperties.Result, ? extends ScalePropertiesBaseConfig> computationResult) {
        var size = computationResult.graph().nodeCount();
        var scaledProperties = computationResult.result().scaledProperties();

        return new DoubleArrayNodePropertyValues() {
            @Override
            public long size() {
                return size;
            }

            @Override
            public double[] doubleArrayValue(long nodeId) {
                return scaledProperties.get(nodeId);
            }
        };
    }
}
